==> nakenchat-2.12.tar.gz: nakenchat-2.12/src/info.c <==
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#ifndef WINDOWS
#include <pthread.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <signal.h>
#include <netdb.h>
#ifndef NO_CRYPT_DOT_H
#include <crypt.h>
#endif
#endif
#include <errno.h>
#include <time.h>
#include <ctype.h>
#ifdef WINDOWS
#include <windows.h>
#endif

#include "globals.h"
#include "functions.h"
#include "language.h"

char help_message[sizeof(HELP)+sizeof(CHAN_HELP)+2];

void channelinfo(int ID)
{
char myString[WHO_BUFFER_SIZE];
char tempString[128];
char cops[128];
int r,buffer_ptr;
#ifdef HIDDEN_CAVES
int t;
#endif
 
  buffer_ptr=0;
  strcpy(myString,CHANNEL_HEADER1);
  buffer_ptr=sizeof(CHANNEL_HEADER1)-1;
  strcpy(&myString[buffer_ptr],"------------------------------------------\r\n");
  buffer_ptr+=sizeof("------------------------------------------\r\n")-1;

  strcpy(&myString[buffer_ptr],CHANNEL_HEADER2);
  buffer_ptr+=sizeof(CHANNEL_HEADER2)-1;

  for(r=1; r<MAXCHAN; r++)
  { 
    if (channels[r][0]!=0)
    {
#ifdef HIDDEN_CAVES
      if ((t=conv_num(channels[r]))<1000 || t>=2000)
#endif
      {
        if (users[ID]->user_level<10 && channelop[r]>=0) 
        {
          if (users[channelop[r]]->user_level==10 && (users[channelop[r]]->uflags&128)!=0)
          { continue; }
        }

        if (channelop[r]>=0)
        { sprintf(cops,"[%d]%s",channelop[r],users[channelop[r]]->username); }
          else
        { strcpy(cops,NOONE); }

        if ((cflags[r]&1)==1)
        { sprintf(tempString,"%-15s %-20s "YES"\r\n",channels[r],cops); }
          else
        { sprintf(tempString,"%-15s %-20s "NO"\r\n",channels[r],cops); }

	strcpy(&myString[buffer_ptr],tempString);
        buffer_ptr=buffer_ptr+strlen(tempString);

        if (buffer_ptr>WHO_BUFFER_SIZE-150)
        {
          message(ID,myString,0);
          buffer_ptr=0;
          myString[0]=0;
        }
      }
    }
  }
  strcpy(&myString[buffer_ptr],"\r\n");
  message(ID,myString,0);
}

void viewbans(int ID)
{
char myString[BANS_BUFFER_SIZE+1024];
char tempString[256];
char *banptr;
int r,c;

  strcpy(myString,CURRENTBAN);
  banptr=bans;
  c=0;

  for (r=0; r<bancount; r++)
  {
    sprintf(tempString,">> %d: %s\r\n",r,banptr);
    strcat(myString,tempString);
    banptr=banptr+(strlen(banptr))+1;
    c=c+strlen(tempString);
    if (c>BANS_BUFFER_SIZE)
    {
      message(ID,myString,0);
      tempString[0]=0;
      c=0;
    }
  }

  sprintf(tempString,BANCOUNT,bancount);
  strcat(myString,tempString);
  message(ID,myString,0);
}

void clientshow(int ID)
{
char myString[maxconn*(MAX_USER_NAME_LENGTH+10)+4];
char temp[80];
int r;

  strcpy(myString,"@\r\n");

  for (r=0; r<maxconn; r++)
  {
    if (users[ID]->user_level<10 && (users[r]->user_level==10 && (users[r]->uflags&128)!=0))
    { continue; }

#ifdef USER_LIST_CHAN
    if (users[r]->inuse==1 && users[r]->channel==users[ID]->channel)
#else
    if (users[r]->inuse==1)
#endif
    {
      sprintf(temp,"+[%d]%s\r\n",r,users[r]->username);
      strcat(myString,temp);
    }
  }
  message(ID,myString,0);
}

void show_levels(int ID)
{
char myString[WHO_BUFFER_SIZE];
char tempString[128];
int r,buffer_ptr,k;

  buffer_ptr=0;

  strcpy(myString,"----------------------------------\r\n");
  k=strlen(myString);

  for (r=0; r<maxconn; r++)
  {
    if (users[r]->inuse==1)
    {
      sprintf(tempString,"[%d]%-20s  %d\r\n",r,users[r]->username,users[r]->user_level);
      strcat(myString,tempString);
      buffer_ptr=buffer_ptr+k;
    }

    if (buffer_ptr>WHO_BUFFER_SIZE-150)
    {
      message(ID,myString,0); 
      buffer_ptr=0;
      myString[0]=0;
    }
  }
  strcat(myString,"----------------------------------\r\n");
  message(ID,myString,0);
}

void who(int ID, char *grep)
{
int c,r,num=-2,trim=0,buffer_ptr;
char myString[WHO_BUFFER_SIZE];
char tempString[1024];
char flags[6];
char channelString[CHANNEL_NAME_LEN];
char location[21];
char idleString[40];
char tempf[60];
time_t myTime;
#ifdef HIDDEN_CAVES
int n;
#endif

  sprintf(tempf,"%%-%ds %%-14s %%s ",MAX_USER_NAME_LENGTH+9);
  sprintf(myString,tempf,WHO_NAME,WHO_CHANNEL,WHO_IDLE);

  if ((serverflags&4)!=0 || users[ID]->user_level==10)
  { strcat(myString,WHO_LOCATION); }
  strcat(myString,"\r\n");

  sprintf(tempf,"[%%d]%%-%ds %%-5s %%-14s %%4s %%s\r\n",MAX_USER_NAME_LENGTH);
  strcpy(location,"");
  myTime=time(NULL);
  while (grep[trim]==' ') trim++;
  if (is_number(&grep[trim])==1) 
  { num=get_num(&grep[trim],ID,NOT_USERID|CAN_BE_NOTHING); grep[trim]=0; }
    else
  {
    r=trim;
    while((grep[r]!='\n' && grep[r]!='\r') &&
           ((grep[r]!=' ' && grep[r]!='\t') && grep[r]!=0)) r++;
    grep[r]=0;
  }

  c=0;
  buffer_ptr=strlen(myString);

  for(r=0; r<maxconn; r++)
  {
    if (users[r]->inuse!=1) continue;

    if (users[ID]->user_level<10 && (users[r]->user_level==10 && 
        (users[r]->uflags&128)!=0))
    { continue; }

    if ((serverflags&1)==1 && (users[ID]->channel!=users[r]->channel &&
         users[ID]->user_level<8)) continue;

    if (num!=-2 && num!=r) continue;
    strcpy(flags,"-----");

    if ((users[r]->uflags&8)==8) flags[0]='H';
    if ((users[r]->gags[ID/8]&(1<<(ID%8)))!=0) flags[0]='G';

    if ((users[r]->uflags&1)==1) flags[1]='B';
    if ((users[ID]->gags[r/8]&(1<<(r%8)))!=0) flags[1]='g';

    if ((channelop[users[r]->channel]==r) && users[r]->channel!=0) flags[2]='O';

    if ((cflags[users[r]->channel]&1)==1) flags[3]='L';

    if ((users[r]->uflags&4)==4) flags[4]='S';

#ifdef HIDDEN_CAVES
    if ((n=conv_num(channels[users[r]->channel]))>=1000 && n<=1999)
    { strcpy(channelString,"Hidden Cave"); }
      else
#endif
    { strcpy(channelString,channels[users[r]->channel]); }

    shorttimediff(myTime,users[r]->idletime,idleString);

    if ((serverflags&4)!=0 || users[ID]->user_level==10)
    { safestrncpy(location,users[r]->location,20); }

    sprintf(tempString,tempf,r,users[r]->username,flags,channelString,
	idleString,location);

    if (grep[trim]==0)
    {
      strcpy(&myString[buffer_ptr],tempString);
      buffer_ptr=buffer_ptr+strlen(tempString);
      c++;
    }
      else
    {
      if (strstr(tempString,&grep[trim])!=NULL)
      {
        strcpy(&myString[buffer_ptr],tempString);
        buffer_ptr=buffer_ptr+strlen(tempString);
        c++;
      }
    }

    if (buffer_ptr>WHO_BUFFER_SIZE-150)
    {
      message(ID,myString,0); 
      buffer_ptr=0;
      myString[0]=0;
    }
  }

  strcpy(&myString[buffer_ptr],"--------------------------------------------------------");
  buffer_ptr=buffer_ptr+sizeof("--------------------------------------------------------")-1;
  sprintf(tempString,WHO_TOTAL,c);
  strcpy(&myString[buffer_ptr],tempString);

  message(ID,myString,0); 
}

#ifdef WHOFILE
int write_whofile()
{
FILE *out;
char idleString[40];
char location[21];
char channelString[CHANNEL_NAME_LEN];
time_t myTime;
int r;

#ifndef WINDOWS
  pthread_mutex_lock(&pthread_mutex);
#else
  EnterCriticalSection(&win_mutex);
/*
  HANDLE mutex_handle;
  struct SECURITY_ATTRIBUTES mutex_attr;
  mutex_attr.nLength=izeof(SECURITY_ATTRIBUTES);
  mutex_attr.lpSecurityDescriptor=null;
  mutex_attr.bInheritHandle=false;

  mutex_handle=CreateMutex(&mutex_attr, true, null); 
*/
#endif

  out=fopen(whofile,"w");
  if (out==0)
  {
    whofile[0]=0;
    return -1;
  }

  myTime=time(NULL);

  for(r=0; r<maxconn; r++)
  {
    if (users[r]->inuse==1)
    {
      shorttimediff(myTime,users[r]->idletime,idleString);

      safestrncpy(location,users[r]->location,20);

#ifdef HIDDEN_CAVES
      if ((n=conv_num(channels[users[r]->channel]))>=1000 && n<=1999)
      { strcpy(channelString,"Hidden Cave"); }
	else
#endif
      { strcpy(channelString,channels[users[r]->channel]); }

      fprintf(out,"[%d]%s\t%s\t%s\t%s\n",r,users[r]->username,channelString,
	idleString,location);

    }
  }

  fclose(out);

#ifndef WINDOWS
  pthread_mutex_unlock(&pthread_mutex);
#else
  LeaveCriticalSection(&win_mutex);
  /* CloseHandle(mutex_handle); */
#endif

  return 0;
}
#endif

void who_short(int ID)
{
char myString[WHO_BUFFER_SIZE];
char tempString[256];
int c,r,buffer_ptr;

  buffer_ptr=0;

  strcpy(myString,"--------------------------------------------------------\r\n");
  buffer_ptr=sizeof("--------------------------------------------------------\r\n")-1;

  c=0;
  for (r=0; r<maxconn; r++)
  {
    if (users[r]->inuse==1)
    {
      if (users[ID]->user_level<10 && (users[r]->user_level==10 && (users[r]->uflags&128)!=0))
      { continue; }

    if ((serverflags&1)==1 && (users[ID]->channel!=users[r]->channel &&
         users[ID]->user_level<8)) continue;

      c++;
      sprintf(tempString,"[%d]%-18s",r,users[r]->username);
      strcpy(&myString[buffer_ptr],tempString);
      buffer_ptr=buffer_ptr+strlen(tempString);
      if (c%3==0)
      { strcat(&myString[buffer_ptr],"\r\n"); buffer_ptr=buffer_ptr+2; }
    }

    if (buffer_ptr>WHO_BUFFER_SIZE-150)
    {
      message(ID,myString,0);
      buffer_ptr=0;
      myString[0]=0;
    }
  }
  if (c%3!=0)
  { strcpy(&myString[buffer_ptr],"\r\n"); buffer_ptr=buffer_ptr+2; }

  strcpy(&myString[buffer_ptr],"--------------------------------------------------------\r\n");
  message(ID,myString,0);
}

void help(int ID)
{
  message(ID,help_message,0);
}

==> nakenchat-2.22.tar.gz: nakenchat-2.22/src/info.c <==
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#ifndef WINDOWS
#include <pthread.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <signal.h>
#include <netdb.h>
#endif
#include <errno.h>
#include <time.h>
#include <ctype.h>
#ifdef WINDOWS
#include <windows.h>
#endif

#include "globals.h"
#include "functions.h"
#include "language.h"

char help_message[sizeof(HELP)+sizeof(CHAN_HELP)+2];

void channelinfo(int ID)
{
char myString[WHO_BUFFER_SIZE];
char tempString[128];
char cops[128];
int r,buffer_ptr;
#ifdef HIDDEN_CAVES
int t;
#endif
 
  buffer_ptr=0;
  strcpy(myString,CHANNEL_HEADER1);
  buffer_ptr=sizeof(CHANNEL_HEADER1)-1;
  strcpy(&myString[buffer_ptr],"------------------------------------------\r\n");
  buffer_ptr+=sizeof("------------------------------------------\r\n")-1;

  strcpy(&myString[buffer_ptr],CHANNEL_HEADER2);
  buffer_ptr+=sizeof(CHANNEL_HEADER2)-1;

  for(r=1; r<MAXCHAN; r++)
  { 
    if (channels[r][0]!=0)
    {
#ifdef HIDDEN_CAVES
      t=conv_num(channels[r]);
      if (t<HIDDEN_CAVES_START || t>HIDDEN_CAVES_END)
#endif
      {
        if (users[ID]->user_level<10 && channelop[r]>=0) 
        {
          if (users[channelop[r]]->user_level==10 && UFLAG_ISSET(channelop[r], USER_HIDDEN_SYSOP))
          { continue; }
        }

        if (channelop[r]>=0)
        { sprintf(cops,"[%d]%s",channelop[r],users[channelop[r]]->username); }
          else
        { strcpy(cops,NOONE); }

        if ((cflags[r]&1)==1)
        { sprintf(tempString,"%-15s %-20s "YES"\r\n",channels[r],cops); }
          else
        { sprintf(tempString,"%-15s %-20s "NO"\r\n",channels[r],cops); }

	strcpy(&myString[buffer_ptr],tempString);
        buffer_ptr=buffer_ptr+strlen(tempString);

        if (buffer_ptr>WHO_BUFFER_SIZE-150)
        {
          message(ID,myString,0);
          buffer_ptr=0;
          myString[0]=0;
        }
      }
    }
  }
  strcpy(&myString[buffer_ptr],"\r\n");
  message(ID,myString,0);
}

void viewbans(int ID)
{
char myString[BANS_BUFFER_SIZE+1024];
char tempString[256];
char *banptr;
int r,c;

  strcpy(myString,CURRENTBAN);
  banptr=bans;
  c=0;

  for (r=0; r<bancount; r++)
  {
    sprintf(tempString,">> %d: %s\r\n",r,banptr);
    strcat(myString,tempString);
    banptr=banptr+(strlen(banptr))+1;
    c=c+strlen(tempString);
    if (c>BANS_BUFFER_SIZE)
    {
      message(ID,myString,0);
      tempString[0]=0;
      c=0;
    }
  }

  sprintf(tempString,BANCOUNT,bancount);
  strcat(myString,tempString);
  message(ID,myString,0);
}

void clientshow(int ID)
{
char myString[maxconn*(MAX_USER_NAME_LENGTH+10)+4];
char temp[80];
int r;

  strcpy(myString,"@\r\n");

  for (r=0; r<maxconn; r++)
  {
    if (users[ID]->user_level<10 && (users[r]->user_level==10 && (UFLAG_ISSET(r, USER_HIDDEN_SYSOP))))
    { continue; }

#ifdef USER_LIST_CHAN
    if (users[r]->inuse==1 && users[r]->channel==users[ID]->channel)
#else
    if (users[r]->inuse==1)
#endif
    {
      sprintf(temp,"+[%d]%s\r\n",r,users[r]->username);
      strcat(myString,temp);
    }
  }
  message(ID,myString,0);
}

void show_levels(int ID)
{
char myString[WHO_BUFFER_SIZE];
char tempString[128];
int r,buffer_ptr,k;

  buffer_ptr=0;

  strcpy(myString,"----------------------------------\r\n");
  k=strlen(myString);

  for (r=0; r<maxconn; r++)
  {
    if (users[r]->inuse==1)
    {
      sprintf(tempString,"[%d]%-20s  %d\r\n",r,users[r]->username,users[r]->user_level);
      strcat(myString,tempString);
      buffer_ptr=buffer_ptr+k;
    }

    if (buffer_ptr>WHO_BUFFER_SIZE-150)
    {
      message(ID,myString,0); 
      buffer_ptr=0;
      myString[0]=0;
    }
  }
  strcat(myString,"----------------------------------\r\n");
  message(ID,myString,0);
}

void who(int ID, char *grep)
{
int c,r,num=-2,trim=0,buffer_ptr;
char myString[WHO_BUFFER_SIZE];
char tempString[1024];
char flags[6];
char channelString[CHANNEL_NAME_LEN];
char location[21];
char idleString[40];
char tempf[60];
time_t myTime;
#ifdef HIDDEN_CAVES
int n;
#endif

  sprintf(tempf,"%%-%ds %%-14s %%s ",MAX_USER_NAME_LENGTH+9);
  sprintf(myString,tempf,WHO_NAME,WHO_CHANNEL,WHO_IDLE);

  if (SERVER_ISSET(SERVER_SHOW_IPS) || users[ID]->user_level==10)
  { strcat(myString,WHO_LOCATION); }
  strcat(myString,"\r\n");

  sprintf(tempf,"[%%d]%%-%ds %%-5s %%-14s %%4s %%s\r\n",MAX_USER_NAME_LENGTH);
  strcpy(location,"");
  myTime=time(NULL);
  while (grep[trim]==' ') trim++;
  if (is_number(&grep[trim])==1) 
  { num=get_num(&grep[trim],ID,NOT_USERID|CAN_BE_NOTHING); grep[trim]=0; }
    else
  {
    r=trim;
    while((grep[r]!='\n' && grep[r]!='\r') &&
           ((grep[r]!=' ' && grep[r]!='\t') && grep[r]!=0)) r++;
    grep[r]=0;
  }

  c=0;
  buffer_ptr=strlen(myString);

  for(r=0; r<maxconn; r++)
  {
    if (users[r]->inuse!=1) continue;

    if (users[ID]->user_level<10 && (users[r]->user_level==10 && 
        UFLAG_ISSET(r, USER_HIDDEN_SYSOP)))
    { continue; }

    if (SERVER_ISSET(SERVER_CHANNEL_DISALLOW) && (users[ID]->channel!=users[r]->channel &&
         users[ID]->user_level<8)) continue;

    if (num!=-2 && num!=r) continue;
    strcpy(flags,"-----");

    if (UFLAG_ISSET(r, USER_HUSH_YELLS)) flags[0]='H';
    // if ((users[r]->gags[ID/8]&(1<<(ID%8)))!=0) flags[0]='G';
    if (IS_GAGGED(r,ID)) flags[0]='G';
    if (UFLAG_ISSET(r, USER_BEEPS)) flags[1]='B';
    // if ((users[ID]->gags[r/8]&(1<<(r%8)))!=0) flags[1]='g';
    if (IS_GAGGED(ID,r)) flags[1]='g';
    if ((channelop[users[r]->channel]==r) && users[r]->channel!=0) flags[2]='O';
    if ((cflags[users[r]->channel]&1)==1) flags[3]='L';
    if (UFLAG_ISSET(r, USER_SQUELCHED)) flags[4]='S';

#ifdef HIDDEN_CAVES
    n=conv_num(channels[users[r]->channel]);
    if (n>=HIDDEN_CAVES_START && n<=HIDDEN_CAVES_END)
    { strcpy(channelString,"Hidden Cave"); }
      else
#endif
    { strcpy(channelString,channels[users[r]->channel]); }

    shorttimediff(myTime,users[r]->idletime,idleString);

    if (SERVER_ISSET(SERVER_SHOW_IPS) || users[ID]->user_level==10)
    { safestrncpy(location,users[r]->location,20); }

    sprintf(tempString,tempf,r,users[r]->username,flags,channelString,
	idleString,location);

    if (grep[trim]==0)
    {
      strcpy(&myString[buffer_ptr],tempString);
      buffer_ptr=buffer_ptr+strlen(tempString);
      c++;
    }
      else
    {
      if (strstr(tempString,&grep[trim])!=NULL)
      {
        strcpy(&myString[buffer_ptr],tempString);
        buffer_ptr=buffer_ptr+strlen(tempString);
        c++;
      }
    }

    if (buffer_ptr>WHO_BUFFER_SIZE-150)
    {
      message(ID,myString,0); 
      buffer_ptr=0;
      myString[0]=0;
    }
  }

  strcpy(&myString[buffer_ptr],"--------------------------------------------------------");
  buffer_ptr=buffer_ptr+sizeof("--------------------------------------------------------")-1;
  sprintf(tempString,WHO_TOTAL,c);
  strcpy(&myString[buffer_ptr],tempString);

  message(ID,myString,0); 
}

#ifdef WHOFILE
int write_whofile()
{
FILE *out;
char idleString[40];
char location[21];
char channelString[CHANNEL_NAME_LEN];
time_t myTime;
int r;

#ifndef WINDOWS
  pthread_mutex_lock(&pthread_mutex);
#else
  EnterCriticalSection(&win_mutex);
/*
  HANDLE mutex_handle;
  struct SECURITY_ATTRIBUTES mutex_attr;
  mutex_attr.nLength=izeof(SECURITY_ATTRIBUTES);
  mutex_attr.lpSecurityDescriptor=null;
  mutex_attr.bInheritHandle=false;

  mutex_handle=CreateMutex(&mutex_attr, true, null); 
*/
#endif

  out=fopen(whofile,"w");
  if (out==0)
  {
    whofile[0]=0;
    return -1;
  }

  myTime=time(NULL);

  for(r=0; r<maxconn; r++)
  {
    if (users[r]->inuse==1)
    {
      shorttimediff(myTime,users[r]->idletime,idleString);

      safestrncpy(location,users[r]->location,20);

#ifdef HIDDEN_CAVES
      n=conv_num(channels[users[r]->channel]);
      if (n>=HIDDEN_CAVES_START && n<=HIDDEN_CAVES_END)
      { strcpy(channelString,"Hidden Cave"); }
	else
#endif
      { strcpy(channelString,channels[users[r]->channel]); }

      fprintf(out,"[%d]%s\t%s\t%s\t%s\n",r,users[r]->username,channelString,
	idleString,location);

    }
  }

  fclose(out);

#ifndef WINDOWS
  pthread_mutex_unlock(&pthread_mutex);
#else
  LeaveCriticalSection(&win_mutex);
  /* CloseHandle(mutex_handle); */
#endif

  return 0;
}
#endif

void who_short(int ID)
{
char myString[WHO_BUFFER_SIZE];
char tempString[256];
int c,r,buffer_ptr;

  buffer_ptr=0;

  strcpy(myString,"--------------------------------------------------------\r\n");
  buffer_ptr=sizeof("--------------------------------------------------------\r\n")-1;

  c=0;
  for (r=0; r<maxconn; r++)
  {
    if (users[r]->inuse==1)
    {
      if (users[ID]->user_level<10 && (users[r]->user_level==10 && UFLAG_ISSET(r, USER_HIDDEN_SYSOP)))
      { continue; }

    if (SERVER_ISSET(SERVER_CHANNEL_DISALLOW) && (users[ID]->channel!=users[r]->channel &&
         users[ID]->user_level<8)) continue;

      c++;
      sprintf(tempString,"[%d]%-18s",r,users[r]->username);
      strcpy(&myString[buffer_ptr],tempString);
      buffer_ptr=buffer_ptr+strlen(tempString);
      if (c%3==0)
      { strcat(&myString[buffer_ptr],"\r\n"); buffer_ptr=buffer_ptr+2; }
    }

    if (buffer_ptr>WHO_BUFFER_SIZE-150)
    {
      message(ID,myString,0);
      buffer_ptr=0;
      myString[0]=0;
    }
  }
  if (c%3!=0)
  { strcpy(&myString[buffer_ptr],"\r\n"); buffer_ptr=buffer_ptr+2; }

  strcpy(&myString[buffer_ptr],"--------------------------------------------------------\r\n");
  message(ID,myString,0);
}

void help(int ID)
{
  message(ID,help_message,0);
}
